@@ -7,7 +7,10 @@ pub fn format(file_texts: &Vec<String>) -> Vec<String> {
 	let mut new_file_texts: Vec<String> = Vec::new();
 	for (i, line) in file_texts.iter().enumerate() {
 		new_file_texts.push(line.to_string());
-		let next_line = file_texts.get(i + 1).unwrap();
+		let next_line = match file_texts.get(i + 1) {
+			Some(x) => x,
+			None => break,
+		};
 		// 関数の終わりの行でかつ次の行が空行ではない場合、空行を挿入する
 		if line.starts_with("}") && next_line != "" {
 			new_file_texts.push(String::from(""));
